@@ -1,4 +1,5 @@
-from fireREST.fmc import Resource
+from fireREST.fmc import Resource, Connection
+from fireREST.fmc.object.fqdn.override import Override
 
 
 class Timezone(Resource):
@@ -8,3 +9,6 @@ class Timezone(Resource):
     MINIMUM_VERSION_REQUIRED_UPDATE = '6.6.0'
     MINIMUM_VERSION_REQUIRED_DELETE = '6.6.0'
 
+    def __init__(self, conn: Connection):
+        super().__init__(conn)
+        self.override = Override(conn)
