@@ -1,4 +1,5 @@
-from fireREST.fmc import Resource
+from fireREST.fmc import Resource, Connection
+from fireREST.fmc.object.vlangrouptag.override import Override
 
 
 class VlanGroupTag(Resource):
@@ -7,3 +8,7 @@ class VlanGroupTag(Resource):
     MINIMUM_VERSION_REQUIRED_GET = '6.1.0'
     MINIMUM_VERSION_REQUIRED_UPDATE = '6.1.0'
     MINIMUM_VERSION_REQUIRED_DELETE = '6.1.0'
+
+    def __init__(self, conn: Connection):
+        super().__init__(conn)
+        self.override = Override(conn)
\ No newline at end of file
